@@ -7,6 +7,7 @@ from typing import Dict, List, Sequence, Iterable, Iterator, Tuple, Literal, Cal
 
 import pysam
 
+from pybiotk.io.fastq import OpenFqGzip
 from pybiotk.intervals import GRange
 from pybiotk.utils import reverse_seq
 
@@ -19,23 +20,32 @@ class FastaFile(pysam.FastaFile):
     def __iter__(self) -> Iterator:
         for reference in self.references:
             yield reference, self[reference]
+            
+    def _stdout(self, reference:str, wrap: bool = True, wrap_len: int = 60):
+        sys.stdout.write(f">{reference}\n")
+        sequence = self[reference]
+        if wrap:
+            seqlen = len(sequence)
+            index = range(seqlen)
+            for i in itertools.islice(index, None, None, wrap_len):
+                sys.stdout.write(f"{sequence[i: i+wrap_len]}\n")
+        else:
+            sys.stdout.write(f"{sequence}\n")
 
-    def stdout(self, referenceList: Optional[Sequence[str]] = None, wrap: bool = True):
+    def stdout(self, referenceList: Optional[Sequence[str]] = None, wrap: bool = True, wrap_len: int = 60):
         if not referenceList:
             referenceList = self.references
-
-        for reference in referenceList:
-            if reference not in self.references:
-                continue
-            sys.stdout.write(f">{reference}\n")
-            sequence = self[reference]
-            if wrap:
-                seqlen = len(sequence)
-                index = range(seqlen)
-                for i in itertools.islice(index, None, None, 60):
-                    sys.stdout.write(f"{sequence[i: i+60]}\n")
-            else:
-                sys.stdout.write(f"{sequence}\n")
+            
+        if len(referenceList) == 1:
+            for reference in self.references:
+                if not re.match(referenceList[0], reference):
+                    continue
+                self._stdout(reference, wrap, wrap_len)
+        else:
+            for reference in referenceList:
+                if reference not in self.references:
+                    continue
+                self._stdout(reference, wrap, wrap_len)
 
     def load_into_dict(self) -> Dict[str, str]:
         self.reference_dict = dict((reference, seq) for reference, seq in self)
@@ -57,6 +67,11 @@ class FastaFile(pysam.FastaFile):
     def dict_fetch(self, reference: str, start: int, end: int, strand: Literal["+", "-"] = "+"):
         assert self.reference_dict is not None
         return self.fetch_use_dict(self.reference_dict, reference, start, end, strand)
+    
+    def to_fastq(self, path: str = "-"):
+        with OpenFqGzip(path) as fq:
+            for reference, sequence in self:
+                fq.write_entry(reference, sequence)
 
 
 class GenomeFile(FastaFile):
@@ -83,7 +98,7 @@ class GenomeFile(FastaFile):
     def chroms_norm(self) -> List[str]:
         chroms = []
         for chrom in self.chroms:
-            if chrom.startswith("chr") or re.match(r"\d.*", chrom):
+            if chrom.startswith("chr") or re.match(r"\d.*|X|Y|M|MT", chrom):
                 chroms.append(chrom)
         return chroms
 
